@@ -2,7 +2,7 @@
 #define __SYST_
 
 #ifndef STRSIZ
-#define STRSIZ 2048
+#define STRSIZ 5000
 #endif
 
 
@@ -26,13 +26,6 @@
 #define ABS(x)          (((x) < 0 ? -(x) : (x)))
 #endif
 
-#ifndef FALSE
-#define FALSE   0
-#endif
-
-#ifndef TRUE
-#define TRUE    1  
-#endif
 
 #ifndef SEEK_SET 
 #include<unistd.h>
@@ -46,4 +39,10 @@ extern  char * trim(char *);
 
 #define strlen(x) (long)strlen(x)
 
+    extern int  setLockFile(char * fname);
+    extern void unLockFile(int id); 
+    extern int writeLockFile(char * fname);
+    extern void sortie(int code);  
+
+
 #endif
