@@ -402,8 +402,8 @@ lVert* getVertex(char*n1,char*n2,char*n3,char*n4)
         int delWorkDir;
         
         delWorkDir=prepareWorkPlace();
-        sprintf(command,"cd %s; %s/sbin/newVertex models  %d  %s  %s %s",
-                       compDir, calchepDir,  modelNum, lib, libDir, vert_txt);                         
+        sprintf(command,"cd %s; %s/sbin/newVertex models 1  %s  %s %s",
+                       compDir, calchepDir, lib, libDir, vert_txt);                         
         ret=system(command);
       
 //        if(ret<0 || WIFSIGNALED(ret)>0 ) exit(10);
