@@ -819,7 +819,7 @@ void setQforParticle(REAL *Q,char*pname)
 
 static void sortWidthTxtList(txtList L)
 {
-  for(;;)
+  if(L) for(;;)
   {
     txtList l=L;
     for(l=L; l && l->next; l=l->next)
