@@ -5,7 +5,6 @@
 #include "crt_util.h"
 int err_code=0;
 
-
 void  errormessage(void)
 {
    switch(err_code)
@@ -16,7 +15,11 @@ void  errormessage(void)
       case 2:
          messanykey(10,10,"Zero denominator");
       break;
-
+      
+      case 3: 
+         messanykey(10,10,"Too many points for integration.");
+      break;
+       
       case 4:
          messanykey(10,10,"Energy too small");
       break;
@@ -25,7 +28,6 @@ void  errormessage(void)
          messanykey(10,10,"Can not evaluate constraints");
       break;
       
-
       case 10:
          messanykey(10,10,"User Break");
       break;
