@@ -195,10 +195,12 @@ static void f7_prog(int mode)
              case 11: sprintf(title+strlen(title)," F(x=%.2E,Q)",x0);     break;
            }
            if(pos==11) xName="Q"; else xName="x";
-           if(on[0]&&on[1]) plot_N(title,z1,z2, xName, LOG, 2, nPoints, f[0],NULL,p_name[0],nPoints,f[1],NULL,p_name[1]);
+           if(on[0]&&on[1]) plot_N("Partice structure functions",xName,z1,z2, LOG,title, 2, 
+                              p_name[0], nPoints, f[0], NULL,
+                              p_name[1], nPoints, f[1], NULL);
            else 
            { if(on[0]) l=0; else l=1;
-              plot_N(title,z1,z2, xName, LOG,1, nPoints, f[l],NULL,p_name[l]);   
+              plot_N("Particle structure function",xName, z1,z2, LOG,title,1,p_name[l], nPoints, f[l],NULL);   
            }  
            put_text(&screen);
          } else messanykey(16,5," Correct input is \n"
@@ -330,13 +332,11 @@ L1:
       char strmen[] ="\030"
                       " BreitWigner range XXX  "
                       " T-channel widths   YYY "
-                      " GI in t-channel    ZZZ "
-                      " GI in s-channel    WWW ";   
+                      " GI in BreitWigner  ZZZ ";
 
       improveStr(strmen,"XXX","%.1f",*BWrange_int);
       improveStr(strmen,"YYY", (*twidth_int)? "ON" : "OFF");
-      improveStr(strmen,"ZZZ",(*gtwidth_int)? "ON" : "OFF");
-      improveStr(strmen,"WWW",(*gswidth_int)? "ON" : "OFF");
+      improveStr(strmen,"ZZZ",(*gswidth_int)? "ON" : "OFF");
 
       menu1(54,6,"",strmen,"n_width_*",&pscr ,&key);
    }
@@ -348,8 +348,7 @@ L1:
               if(*BWrange_int>999.9) *BWrange_int=999.9;
               break;
      case 2:  *twidth_int = ! *twidth_int; break;
-     case 3:  *gtwidth_int =! *gtwidth_int; break; 
-     case 4:  *gswidth_int =! *gswidth_int; break;
+     case 3:  *gswidth_int =! *gswidth_int; break;
    }    
     goto L1;
 } /* w_men__ */
