@@ -323,7 +323,7 @@ void show_depend(int x, int y)
                *vPos=val2; 
                for(i=0;i<nModelFunc;i++) varValues[1+nModelVars+i]=allfunc[i];
 
-               if(!(NaN||Esc)) plot_1(xMin,xMax,nPoints,f,NULL,"Plot",
+               if(!(NaN||Esc)) plot_1(xMin,xMax,nPoints,f,NULL,"Parameter depndence",
                                name2,name1);
                                
             } else messanykey(16,5," Correct input is \n"
