@@ -51,10 +51,10 @@ double calcPhysVal(char key,char * lv,double*V)
             q3 = V[np2+3];
             mq = sqrt(q1*q1 + q2*q2 + q3*q3);
             
-            cs = (p1*q1 + p2*q2)/sqrt( (p1*p1 + p2*p2)*(q1*q1 + q2*q2) );
-            cs = acos(cs);
+            cs = (p1*q1 + p2*q2)/sqrt( (p1*p1 + p2*p2)*(q1*q1 + q2*q2) );    
+            if(cs>=1) cs=0; else    cs = acos(cs);
                    
-            dl = (mp + p3) * (mq - q3)  / (mp - p3) / (mq +q3);
+            dl = (mp + p3) * (mq - q3)  / (mp - p3) / (mq +q3);            
             dl = 0.5*log(dl);
             
             return sqrt(dl*dl + cs*cs);
