@@ -1,6 +1,7 @@
 #include"num_in.h"
 
 REAL Helicity[2]={0.,0.};
+REAL N_pol_11_,N_pol_12_,N_pol_21_,N_pol_22_;
 
 int  CalcConst=0;
 
@@ -97,16 +98,18 @@ int prepDen(int nden, int nin,double BWrange2, REAL*dmass,REAL*dwidth, char** Qt
    if(WIDTH_FOR_OMEGA && !stype(nin,Qtxt[i])) dwidth[i]=0.01*fabs(dmass[i]);
 #endif
 
-  Q1[i]=dmass[i]*dmass[i]-sqrMom(nin,Qtxt[i],momenta);   
-  if(dwidth[i])
-  {  REAL w,w2, q2=Q1[i]*Q1[i];
-     w=dmass[i]*dwidth[i];
-     w2=w*w;
-     if(q2>BWrange2*w2) { if(q2<(BWrange2+1)*w2) q2=(BWrange2+1) *w2; w2=0; }
+  double s=sqrMom(nin,Qtxt[i],momenta);
+  Q1[i]=dmass[i]*dmass[i]-s;
+  if(dwidth[i]>0 && dmass[i]>0 &&  s>0 )
+  {  
+     REAL w=sqrt(s)*dwidth[i], q2=Q1[i]*Q1[i];
+     w=sqrt(s)*dwidth[i];
+     
+     if(q2>(BWrange2+1)*w*w)  w=0; else if(q2> BWrange2*w*w) w=((BWrange2+1)*w*w-q2)/w; 
 
-     Q2[i]=1/(q2+w2);
+     Q2[i]=1/(q2+w*w);
      Q0[i]=Q2[i]*Q1[i]*Q1[i];
-     Q1[i]=1/(Q1[i] + I*sqrt(w2));
+     Q1[i]=1/(Q1[i] + I*w);
   } else
   {  if(cabs(Q1[i]) < 100*s0max) err=2;
 //     if(cabs(Q1[i]) < 100*s0max)   printf("i=%d s0max=%E cabs(Q1[i]=%E  eps=%E E=%E\n",i, (double)s0max,(double)cabs(Q1[i]),(double)computer_eps,
