@@ -7,9 +7,9 @@
 #define __PLOT__
 
 
-extern int   plot_N(char*title,  double xMin, double xMax, char*xName, int xScale, int N,...);
-extern int   plot_Nar(char*file, char*title,  double xMin, double xMax, char*xName,  int xScale, int N, int *Dim,
-               double **f,double**ff,char**Y);
+extern int   plot_N(             char*title, char*xName,  double xMin, double xMax,  int xScale, char*yName, int N,...);
+extern int   plot_Nar(char*file, char*title, char*xName, double xMin, double xMax,   int xScale, char*yName,int N, 
+       char**Y, int *Dim,  double **f,double**ff);
 
 extern void   plot_1(double xMin, double xMax, int dim, 
                     double *f, double *ff,char* upstr, char* xstr, char* ystr);
