@@ -178,7 +178,7 @@ static int colList[]={Black,Blue,Red,Yellow,Magenta, Green,Cyan, Brown,LightGray
 static char*colListTxt[]={"Black","Blue","Red","Yellow","Magenta", "Green","Cyan", "Brown","LightGray",
               "DarkGray", "LightBlue","LightGreen","LightCyan","LightRed","LightMagenta","White"};
 
-static void  gaxes(char* upstr, char* xstr, int N, char**Y)
+static void  gaxes(char* upstr, char* xstr, char*ystr, int N, char**Y)
 {
 
    double  xmax,xmin,ymax,ymin,aa,step; 
@@ -286,13 +286,17 @@ static void  gaxes(char* upstr, char* xstr, int N, char**Y)
      {  tg_settextjustify(RightText,TopText); 
         tg_outtextxy(X2,Y1 + hash + th ,xstr);
      }else
-     {  tg_settextjustify(LeftText,CenterText);
-        goto_xy(10,2);
-        for(i=0;i<N;i++)   
-        {  scrcolor(colList[i],bkcolor);
-           print("%s",Y[i]);
-           if(i<N-1) print("; ");
-        }       
+     {  tg_settextjustify(LeftText,BottomText);
+        tg_outtextxy(X1-6*tw,Y2-th/2+1 ,ystr);
+        if(Y)
+        {
+          goto_xy(15,3);   
+          for(i=0;i<N;i++) if(strlen(Y[i])>0)   
+          {  scrcolor(colList[i],bkcolor);
+             print("%s",Y[i]);
+             if(i<N-1) print("; ");
+          }       
+        }
      }
    }
      
@@ -431,7 +435,7 @@ static void plot_hist(double xMin,double xMax,int dim, double *f,double *df)
 
 
 static int writetable1(char * filename, double xMin,double xMax, double yMin, double yMax,
-     char*x_str,char*upstr, 
+     char*x_str, char*upstr, char*y_str,
  int N, int*Dim, double**f,double**df,char**Y)  
 { 
    FILE *     outfile;
@@ -446,19 +450,23 @@ static int writetable1(char * filename, double xMin,double xMax, double yMin, do
    for(i=0;i<N;i++) if(maxDim<Dim[i]) maxDim=Dim[i];
    outfile=fopen(filename,"w");
    if(outfile==NULL) return 1;
+   fprintf(outfile,"#type  1 %% 1d plot\n");
    fprintf(outfile,"#title %s\n",upstr);
-   fprintf(outfile,"#yName ");
+   fprintf(outfile,"#xName %s\n",x_str);
+   fprintf(outfile,"#xMin %E\n",xMin);
+   fprintf(outfile,"#xMax %E\n",xMax);
+   
+   fprintf(outfile,"#xScale %d\n",logX);
+   fprintf(outfile,"#yName %s\n",y_str);
+   fprintf(outfile,"#dataList ");
    for(k=0;k<N;k++)
    {  fprintf(outfile,"%s",Y[k]);
       if(df[k])  fprintf(outfile,"{h}"); else fprintf(outfile,"{c} ");
    } 
+
    fprintf(outfile,"\n");
-   fprintf(outfile,"#xName %s\n",x_str);
-   fprintf(outfile,"#xMin %E\n",xMin);
-   fprintf(outfile,"#xMax %E\n",xMax);
    fprintf(outfile,"#xDim "); for(i=0;i<N;i++) fprintf(outfile," %d",Dim[i]); fprintf(outfile,"\n");
-   
-   fprintf(outfile,"#xScale %d\n",logX);
+
        
    fprintf(outfile,"#---   starting of data ---\n#");
    for(k=0;k<N;k++) 
@@ -487,7 +495,7 @@ static int writetable1(char * filename, double xMin,double xMax, double yMin, do
 }
 
 static void  writeGNU(char*fname, double xMin,double xMax, double yMin, double yMax, 
-     char*x_str,char*upstr,  int N, int*Dim, char* type,char**Y)  
+     char*x_str, char*y_str,char*upstr,  int N, int*Dim, char* type,char**Y)  
 {  char       filename[100], buff[STRSIZ],command[100];
    FILE *     outfile;
    int        i,k;
@@ -506,7 +514,7 @@ static void  writeGNU(char*fname, double xMin,double xMax, double yMin, double y
    fprintf(outfile,"# set terminal latex \n");
    fprintf(outfile,"# set title  '%s'\n",upstr);
    fprintf(outfile," set xlabel '%s'\n",x_str);
-   if(N==1) fprintf(outfile," set ylabel '%s'\n",Y[0]);
+   if(strlen(y_str)>0) fprintf(outfile," set ylabel '%s'\n",y_str);
    fprintf(outfile," xMin=%E\n",xMin);
    fprintf(outfile," xMax=%E\n",xMax);
    fprintf(outfile," yMin=%E\n",yMin);
@@ -549,7 +557,7 @@ static void  writeGNU(char*fname, double xMin,double xMax, double yMin, double y
 
 
 static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double yMax,
-     char*x_str,char*upstr, 
+     char*x_str, char*y_str,char*upstr, 
  int N, int*Dim, char*type,char**Y)  
 {  char       filename[100], buff[STRSIZ],command[100];
    FILE *     outfile;
@@ -653,7 +661,7 @@ static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double
    }
           
    fprintf(outfile," set txci 1 \n" );
-   if(N==1) fprintf(outfile," atitle  '%s' '%s'\n",x_str,Y[0]);
+   if(strlen(y_str)>0) fprintf(outfile," atitle  '%s' '%s'\n",x_str,y_str);
    else     fprintf(outfile," atitle  '%s'\n",x_str);
    fprintf(outfile," pic/print  %s.eps\n",fname); 
 
@@ -664,7 +672,7 @@ static void  writePAW(char *fname,  double xMin,double xMax, double yMin, double
 
 
 static void  writeROOT(char *fname,  double xMin,double xMax, double yMin, double yMax, 
-     char*x_str,char*upstr, int N, int*Dim, char*type,char**Y)  
+     char*x_str, char* y_str, char*upstr,  int N, int*Dim, char*type,char**Y)  
 {  char       filename[100],basename[100], buff[STRSIZ];
    FILE *     outfile;
    int        i,k;
@@ -695,7 +703,7 @@ fprintf(outfile,
    if(i<0) i=0;
    fprintf(outfile,"void %s(void)\n{\n",basename+i);
    
-   fprintf(outfile," TCanvas *Can = new TCanvas(\"c\",\"%s\",200,10,600,400);\n",upstr);
+   fprintf(outfile," TCanvas *Can = new TCanvas(\"c\",\"%s\",200,10,700,400);\n",upstr);
    fprintf(outfile," double xMin=%E, xMax=%E, yMin=%E, yMax=%E;\n",xMin,xMax,yMin,yMax);
    fprintf(outfile," char buff[2000];\n");
    fprintf(outfile," double "); 
@@ -723,7 +731,7 @@ fprintf(outfile,
        
    fprintf(outfile," TH1F *hr = Can->DrawFrame(xMin,yMin,xMax,yMax);\n");
    fprintf(outfile," hr->SetXTitle(\"%s\");\n",x_str);   
-   if(N==1) fprintf(outfile," hr->SetYTitle(\"%s\");\n",Y[0]);   
+   if(strlen(y_str)>0)fprintf(outfile," hr->SetYTitle(\"%s\");\n",y_str);   
 
    int maxDim=0;
    for(k=0;k<N;k++) if(Dim[k]>maxDim) maxDim=Dim[k];
@@ -790,7 +798,7 @@ fprintf(outfile,
 }
 
 static void  writePython(char *fname,  double xMin,double xMax, double yMin, double yMax,
-     char*x_str, char*upstr, int N, int*Dim, char*type, char**Y)  
+     char*x_str, char*y_str, char*upstr, int N, int*Dim, char*type, char**Y)  
 {  char       filename[100],basename[100], buff[STRSIZ];
    FILE *     outfile;
    int        i,k;
@@ -826,7 +834,7 @@ static void  writePython(char *fname,  double xMin,double xMax, double yMin, dou
 
    fprintf(outfile,"plt.title('%s')\n", upstr);
    fprintf(outfile,"plt.xlabel('%s',fontsize=16)\n", x_str);
-   if(N==1) fprintf(outfile,"plt.ylabel('%s',fontsize=16)\n", Y[0]);
+   if(strlen(y_str)>0) fprintf(outfile,"plt.ylabel('%s',fontsize=16)\n", y_str);
    if(logX) fprintf(outfile,"plt.xscale('log')\n");    else fprintf(outfile,"plt.xscale('linear')\n"); 
    if(logY)fprintf(outfile,"plt.yscale('log')\n"); else fprintf(outfile,"plt.yscale('linear')\n");
    fprintf(outfile,"xmin=%E\n",xMin);
@@ -834,7 +842,7 @@ static void  writePython(char *fname,  double xMin,double xMax, double yMin, dou
    fprintf(outfile,"plt.xlim(xmin,xmax)\n");
    fprintf(outfile,"plt.ylim(%E,%E)\n",yMin,yMax);
    for(k=0;k<N;k++) if(type[k]=='s') break;
-   if(k!=N) // interpalation is needed
+   if(k!=N) // interpolation is needed
    { if(logX)
      { fprintf(outfile,"li=np.linspace(log(xmin), log(xmax),300)\n");
        fprintf(outfile,"xi=np.exp(li)\n");
@@ -912,102 +920,6 @@ static void  writePython(char *fname,  double xMin,double xMax, double yMin, dou
    fprintf(outfile,"plt.savefig('%s.pdf')\n", basename);
    fprintf(outfile,"plt.show()\n"); 
         
-#ifdef UseDeleted 
-    
-   for(i=strlen(basename)-1; i>=0 && basename[i]!='/';i--);
-   if(i<0) i=0;
-   fprintf(outfile,"void %s(void)\n{\n",basename+i);
-   
-   fprintf(outfile," TCanvas *Can = new TCanvas(\"c\",\"%s\",200,10,600,400);\n",upstr);
-   fprintf(outfile," double xMin=%E, xMax=%E, yMin=%E, yMax=%E;\n",xMin,xMax,yMin,yMax);
-   fprintf(outfile," char buff[2000];\n");
-   fprintf(outfile," double "); 
-   for(k=0;k<N;k++){ fprintf(outfile," X%d[%d],dX%d[%d]",k,Dim[k],k,Dim[k]); 
-                     if(k<N-1) fprintf(outfile,","); else  fprintf(outfile,";\n");
-                   }           
-   if(logX)
-   { 
-        fprintf(outfile," Can->SetLogx();\n");
-        for(k=0;k<N;k++) fprintf(outfile," for(int i=0;i<%d;i++){ X%d[i]=xMin*pow(xMax/xMin,(i+0.5)/%d);dX%d[i]=X%d[i]*(pow(xMax/xMin,0.333/%d)-1);} \n", Dim[k],k,Dim[k],k,k,Dim[k]);    
-   } 
-   else for(k=0;k<N;k++) fprintf(outfile," for(int i=0;i<%d;i++){ X%d[i]=xMin+(i+0.5)*(xMax-xMin)/%d; dX%d[i]=(xMax-xMin)/3./%d;}\n", Dim[k],k,Dim[k],k,Dim[k]);
-         
-
-   if(logX)fprintf(outfile," double Xtext = xMin*pow(xMax/xMin,0.3);\n");  
-   else    fprintf(outfile," double Xtext = xMin+0.3*(xMax-xMin);\n");  
-   fprintf(outfile," double Ytext= yMax;\n");
-
-   if(logY)   
-   {
-     fprintf(outfile," Can->SetLogy();\n");
-     fprintf(outfile," double dYtext=pow(yMax/yMin,0.055);\n");
-   } else fprintf(outfile," double dYtext= (yMax-yMin)/15;\n");
-   
-       
-   fprintf(outfile," TH1F *hr = Can->DrawFrame(xMin,yMin,xMax,yMax);\n");
-   fprintf(outfile," hr->SetXTitle(\"%s\");\n",x_str);   
-   if(N==1) fprintf(outfile," hr->SetYTitle(\"%s\");\n",Y[0]);   
-
-   int maxDim=0;
-   for(k=0;k<N;k++) if(Dim[k]>maxDim) maxDim=Dim[k];
-   
-   for(k=0;k<N;k++)
-   {  
-     fprintf(outfile," double  Y%d[%d];\n",k,maxDim);
-     sprintf(format+strlen(format)," %%lf");
-     sprintf(read+strlen(read)," ,Y%d+i",k);
-     if(type[k]=='h')
-     {  fprintf(outfile," double  dY%d[%d];\n",k,maxDim);  
-        sprintf(format+strlen(format)," %%lf");
-        sprintf(read+strlen(read)," ,dY%d+i",k);
-     }
-   }
-   
-   fprintf(outfile, " FILE*f=fopen(\"%s\",\"r\");\n",fname);
-   fprintf(outfile, " for(int i=0;i<%d;)\n {\n",maxDim);
-   fprintf(outfile, "  fscanf(f,\"%%[^\\n]%%*c\",buff);\n");
-   fprintf(outfile, "  if(buff[0]!='#') {");
-   fprintf(outfile, "  sscanf(buff,\"%s\" %s); i++;", format, read);
-   fprintf(outfile, "    }\n }\n");
-   fprintf(outfile, " fclose(f);\n");
-
-//   fprintf(outfile, " double dX[%d];\n",dim);
-//   fprintf(outfile, " for(int i=0;i<%d;i++) dX[i]=(xMax-xMin)/%d/3.;\n",dim,dim);
-
-   fprintf(outfile, " TLatex ltx;\n");
-   fprintf(outfile, " ltx.SetTextFont(42);\n");
-   fprintf(outfile, " ltx.SetTextSize(0.04);\n");
-           
-   for(k=0;k<N;k++)
-   { if(type[k]=='h') 
-     {  fprintf(outfile,"   TGraphErrors *gr%d =new TGraphErrors(%d,X%d,Y%d,dX%d,dY%d);\n",k,Dim[k],k,k,k,k);
-        fprintf(outfile,"   gr%d->SetLineColor(%d);\n",k,k+1); 
-        fprintf(outfile,"   gr%d->Draw(\"P\");\n",k);
-     } else 
-     {   
-       fprintf(outfile, "   TGraph *gr%d = new TGraph (%d,X%d,Y%d);\n",k,Dim[k],k,k); 
-       fprintf(outfile, "   gr%d->SetLineColor(%d);\n",k,k+1);
-       if(type[k]=='l') fprintf(outfile, "   gr%d->Draw(\"L\");\n",k);
-       else fprintf(outfile, "   gr%d->Draw(\"C\");\n",k);
-     }
-     if(N>1 && Y[k][0])
-     {
-        if(logY) fprintf(outfile,"   Ytext/=dYtext;\n"); else  fprintf(outfile,"  Ytext-=dYtext;\n");
-/*
-        fprintf(outfile,"  TText *t%d = new TText(Xtext,Ytext,\"%s\");\n",k,Y[k]);
-        fprintf(outfile,"  t%d->SetTextColor(%d);\n",k,k+1);
-        fprintf(outfile,"  t%d->SetTextFont(42);\n",k);
-        fprintf(outfile,"  t%d->SetTextSize(0.03);\n",k);
-        fprintf(outfile,"  t%d->Draw();\n",k);
-*/        
-        fprintf(outfile,"    ltx.SetTextColor(%d);\n",k+1);
-        fprintf(outfile,"    ltx.DrawLatex(Xtext,Ytext,\"%s\");\n",Y[k]);         
-     } 
-   }  
-   fprintf(outfile," Can->Print(\"%s.pdf\");\n",basename);
-   
-   fprintf(outfile,"}\n");
-#endif   
    fclose(outfile);
    
    messanykey(10,12,filename);
@@ -1094,6 +1006,7 @@ double * f, double *df, char*  upstr,  char*  x_str, char*  y_str)
    fprintf(outfile,"#yMin %E\n",yMin);
    fprintf(outfile,"#yMax %E\n",yMax);
    fprintf(outfile,"#yDim %d\n",dimY);
+   fprintf(outfile,"%dataList {h}\n");
      
    fprintf(outfile,"#---   starting of data ---\n");
    fprintf(outfile,"#--- F ---    --- dF ---\n");
@@ -1304,8 +1217,8 @@ double * f, double *df, char*  upstr,  char*  x_str, char*  y_str)
 
 
    
-int  plot_Nar( char*file, char*  title, double xMin, double xMax, char*xName, int xScale,
-               int N, int*Dim, double **f,double**ff,char**Y)
+int  plot_Nar( char*file, char*  title,char*xName, double xMin, double xMax, int xScale,
+             char * yName,  int N,char**Y, int*Dim, double **f,double**ff)
 {   
   void *     prtscr;  
   int i,k,nCol0,nRow0,key;
@@ -1313,6 +1226,7 @@ int  plot_Nar( char*file, char*  title, double xMin, double xMax, char*xName, in
   char        f_name[STRSIZ], menustr[STRSIZ], buff[STRSIZ];
   char * type=malloc(sizeof(char)*N);
   static int mouseXY=0;
+
   
   for(i=0;i<N;i++) 
   {            for(k=0;k<Dim[i];k++) if(!isfinite( f[i][k])) return 1;
@@ -1344,7 +1258,7 @@ REDRAW:
    nRow0=maxRow();
    clr_scr(fgcolor,bkcolor);
    
-   gaxes(title,xName,N,Y);
+   gaxes(title,xName,yName,N,Y);
 
    for(i=0;i<N;i++)
    {   fColor=colList[i];
@@ -1466,7 +1380,7 @@ REDRAW:
                 correctStr(10,17,"File name: ",baseF,29,1);
                 trim(baseF);
                 err=writetable1(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,
-                    xName,title,N, Dim, f,ff,Y);
+                    xName,title, yName,  N, Dim, f,ff,Y);
                 if(err) 
                 {         
                    sprintf(buff,"Can not create file '%s'\n",baseF);
@@ -1489,15 +1403,15 @@ contin:
              {  menu1(nCol0-15, 6, "For Package",fileMenu,"n_graph_*",NULL,&m);             
                 switch(m)        
                 {  case 1: writeROOT(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,
-                                    xName,title,N,Dim,type,Y);
+                                    xName, yName,title,N,Dim,type,Y);
                    break;
                    case 2: writePAW(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,
-                                    xName,title,N,Dim,type,Y);
+                                    xName,yName,title,N,Dim,type,Y);
                    break;                  
                    case 3: writeGNU(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,           
-                                    xName,title,N,Dim,type,Y);
+                                    xName,yName,title,N,Dim,type,Y);
                    case 4: writePython(baseF,xMin,xMax,grafminmax.ymin,grafminmax.ymax,
-                                    xName,title,N,Dim,type,Y);
+                                    xName,yName,title,N,Dim,type,Y);
                                                        
                    break;
 //                   case 4:
@@ -1534,7 +1448,7 @@ exi:
    return 0;
 }
 
-int  plot_N(char*title, double xMin, double xMax,  char*  xName, int xScale, int N,...)
+int  plot_N(char*title, char*  xName, double xMin, double xMax, int xScale, char *yName, int N,...)
 { int err, k,i;
                                                                
   double **f; double**ff; char**Y;
@@ -1553,14 +1467,15 @@ int  plot_N(char*title, double xMin, double xMax,  char*  xName, int xScale, int
    va_start(ap,N);
    
    for(i=0;i<N;i++) 
-   { Dim[i]=va_arg(ap,int); 
+   { 
+     Y[i]=va_arg(ap,char*);
+     Dim[i]=va_arg(ap,int); 
      f[i]=va_arg(ap,double*);
      ff[i]=va_arg(ap,double*);
-     Y[i]=va_arg(ap,char*);
    }  
    va_end(ap);
 
-   err=plot_Nar(NULL,title,xMin,xMax,xName,xScale, N,Dim,f,ff,Y);
+   err=plot_Nar(NULL,title,xName,xMin,xMax,xScale,yName, N,Y, Dim,f,ff);
 
    free(f);free(ff);free(Y),free(Dim);
    return err;
@@ -1568,7 +1483,9 @@ int  plot_N(char*title, double xMin, double xMax,  char*  xName, int xScale, int
 
 void   plot_1(double xMin, double xMax, int dim,
                     double *f, double *ff,char* title, char* xstr, char* ystr)
-{  plot_Nar(NULL,title,xMin, xMax,xstr,0, 1,&dim,&f,&ff, &ystr); } 
+{ char* zero=""; 
+  plot_Nar(NULL,title,xstr, xMin, xMax,0, ystr, 1, &zero, &dim,&f,&ff); 
+} 
                     
 
 void plot_2D(double hMin1,double hMax1,int nBin1,double hMin2,double hMax2,int nBin2,
@@ -1606,7 +1523,7 @@ REDRAW:
    nRow0=maxRow();
    clr_scr(fgcolor,bkcolor);
 
-   gaxes(upstr,xstr,1,&ystr);
+   gaxes(upstr,xstr,ystr,1,NULL);
  
    { int i,j;
      for(i=0;i<nBin1;i++) for(j=0;j<nBin2;j++)
