@@ -1,12 +1,17 @@
 #ifndef __RFACTOR_
 #define __RFACTOR_
 #include"lnum.h"
+#include"procvar.h"
+
+#include "ghosts.h"
+
+
 
 #define vmptr struct vmrec * 
 typedef struct vmrec 
    { 
       vmptr        next; 
-      char         name[7];
+      char         name[VAR_NAME_SIZE_EXT];
       unsigned         deg;
    }  vmrec;
 #undef vmptr
@@ -63,5 +68,10 @@ extern void  diagramsrfactors(hlpcsptr     gst,
                               s_listptr *  s,
                               rmptr     *  totf);
 
-extern pointer  read_rmonom(char *  txt);
+extern void*  read_rmonom(char *  txt);
+
+extern int  rmonomGG(rmptr   r);
+
+extern int  rmonomI(rmptr   r);
+
 #endif
