@@ -109,7 +109,7 @@ int  makenewmodel(void)
     {  messanykey(10,10,"Such directory is absent");
        continue;
     }
-    while(dp=readdir(dirPtr))
+    while((dp=readdir(dirPtr)))
     { char tail[100];
       int n;
       if(sscanf(dp->d_name,"vars%d.%s",&n,tail)==2 && strcmp(tail,"mdl")==0)
@@ -167,7 +167,7 @@ int  makenewmodel(void)
          }else 
          {
            fscanf(f,"%*[^\n]%*c");
-           while( s=fread(ch,1,1000,f)) fwrite(ch,1,s,g);
+           while((s=fread(ch,1,1000,f))) fwrite(ch,1,s,g);
            fclose(f); 
          }  
          fclose(g);  
