@@ -6,22 +6,29 @@
 #include <pthread.h>
 
 
-static FILE*f=NULL;
 static pthread_mutex_t keyN=PTHREAD_MUTEX_INITIALIZER;
 
+typedef struct fList { struct fList* next; char fName[30];} fList;
+
+static fList * list=NULL;
+
+
 static void * pCompile_cycle(int * input)
 {  
   char command[100];
-  char fName[12];    
   for(;;)
-  { char fName[12];
+  { 
+    char*fName=NULL;   
     pthread_mutex_lock(&keyN);
-      if(f && 1!=fscanf(f,"%s",fName)) { fclose(f); f=NULL; }    
+     if(list) 
+     { fName=list->fName;
+       list=list->next;
+     }    
     pthread_mutex_unlock(&keyN);
-    if(!f) return NULL;
-    sprintf(command," $CC -c $CFLAGS %s; if(test $? -eq 0) then  rm %s;fi\n",
-    fName,fName);
-    system(command);
+    if(fName)
+    {  sprintf(command," $CC -c $CFLAGS %s; if(test $? -eq 0) then  rm %s;fi\n",fName,fName);     
+       system(command);
+    } else return NULL;  
   } 
   return NULL;
 }
@@ -36,26 +43,25 @@ int main(int argc, char** argv)
    if(argc!=2) return 1;
    if(1!=sscanf(argv[1],"%d",&nParProc)) return 2;
    if(nParProc<=0) nParProc=1;
-
-   f=fopen("make-j_list.txt","w");
    
    dirPtr=opendir("./");   
    while((dp=readdir(dirPtr)))
    { char *c=strstr(dp->d_name,".c");
-     if(c&&c[2]==0) { fprintf(f,"%s\n",dp->d_name); Ntot++;}
+     if(c&&c[2]==0) { fList *tmp=malloc(sizeof(fList));
+                      tmp->next=list;
+                      strcpy(tmp->fName,dp->d_name);
+                      list=tmp; 
+                       Ntot++;
+                    }   
    }  
-   closedir(dirPtr);
-   fclose(f);
+   closedir(dirPtr);   
    if(!Ntot) return 0;
-   
-   f=fopen("make-j_list.txt","r");
+   if(nParProc>Ntot) nParProc=Ntot;
    { pthread_t *threads = malloc(nParProc*sizeof(pthread_t));
      int k;  
      for (k=0;k<nParProc;k++) pthread_create(threads+k,NULL,pCompile_cycle,NULL);  
      for (k=0;k<nParProc;k++) pthread_join(threads[k],NULL);
      free(threads);
-  }
-   
-  unlink("make-j_list.txt"); // closed by threads
-  return 0;   
+   }
+   return 0;   
 }
