@@ -215,7 +215,7 @@ static int enter_h(int * y,char* name,int num,int scat)
     }   
     if(name[strlen(name)-1]=='%')
     { 
-      if( !scat || nout||strcmp(prtclbase1[j].massidnt,"0") || 
+      if( !scat || nout|| (  prtclbase1[j].spin==2 && strcmp(prtclbase1[j].massidnt,"0")  ) || 
           (prtclbase1[j].spin!=1 && prtclbase1[j].spin!=2) || 
           strchr("LR",prtclbase1[j].hlp)
         ) 
