@@ -347,7 +347,7 @@ static int  readvars(int  check)
       nLine=modelvars[vSorted[i]].line;  
       rderrpos=1;
       errorMessage("Name","duplicate name '%s'",modelvars[vSorted[i]].varname);  
-      return 1;
+      goto errExi1;
    }
    if(check) rd=rd_33;else rd=rd_33_nocheck;
 // Completeness 
@@ -378,7 +378,7 @@ static int  readvars(int  check)
        if(depQ   &&  depQ1>i)  depQ1=i;
        if(check&&aWidth)
        { errorMessage("Expression","%s","'aWidth()' - unlegal function");
-         return 0;
+         goto errExi1;
        }  
    }   
          
