@@ -1,4 +1,4 @@
-//#define _LONG_      to use long double type in numerical calculations
+#define _LONG_      to use long double type in numerical calculations
 //#define _QUAD16_    to use quadrouple precision for icc compiler. It has to be accompany with compiler option '-Qoption,cpp,--extended_float_type'  
 
 #ifndef __NTYPE__
